@@ -7,7 +7,12 @@ except:
 
 
 class Genome:
-    def __init__(self, topology):
+    def __init__(self, topology: dict):
+        """Initialize a genome from a GAIuS agent topology (dict)
+
+        Args:
+            topology (dict, required): GAIuS agent topology
+        """
         self.topology = topology
         self.agent = self.topology['agent']
         self.description = self.topology['description']
@@ -42,23 +47,54 @@ class Genome:
         return
 
     def get_nodes(self):
+        """Return a tuple of :samp:`primitive node names`, :samp:`manipulative node names` from the topology"""
         return self.agent_genome['primitives'], self.agent_genome['manipulatives']
 
     def get_actions(self):
+        """Return a list of ACTIONs in the topology
+
+        .. warning::
+            .. deprecated:: 12.0 (Kehl)
+
+                ACTIONs are not actively used in GAIuS topology creation
+        """
         return self.action_ids
 
     def get_primitive_map(self):
+        """Get a map of node names to primitive ids in the GAIuS agent topology
+
+        Example:
+            .. code-block:: python
+            
+                >>> agent = AgentClient(agent_info)
+                >>> agent.connect()
+                >>> agent.genome.get_primitive_map()
+                {'P1': 'p46b6b076c'}
+        """
         return self.primitive_map
 
     def get_manipulative_map(self):
+        """Get a map of the manipulatives connected to each primitive node in the GAIuS agent topology
+
+        Returns:
+            dict: dictionary of manipulatives mappings in the topology
+        """
         return self.manipulative_map
 
     def change_genes(self, p_id, gene_data):
+        """Change the genes of a primitive in the Genome's cache
+
+        Args:
+            p_id (str): primitive id of the node to edit
+            gene_data (dict): dictionary of genes to update in the Genome's cache
+        """
         for key, value in gene_data.items():
             self.agent_genome['primitives'][p_id][key] = value
         return
 
     def display(self):
+        """Display the Genome topology in Cytoscape
+        """
         return Cytoscape(data=self.topology, visual_style=self.style_obj, layout={'height': '500px'},
                          background='white')
 
