@@ -10,7 +10,16 @@ def principal_delta(principal, other, potential):
         return principal + (abs(other - principal)*potential)
 
 def model_per_emotive(ensemble, emotive, potential_normalization_factor):
-    "Using a Weighted Moving Average, though the 'moving' part refers to the prediction index."
+    """Using a Weighted Moving Average, though the 'moving' part refers to the prediction index.
+
+    Args:
+        ensemble (list, required): The prediction ensemble to use in computations
+        emotive (_type_): The emotive to compute a moving average of
+        potential_normalization_factor (_type_): Divisor to normailize the potential value of each prediction
+
+    Returns:
+        _type_: _description_
+    """
     ## using a weighted posterior_probability = potential/marginal_probability
     ## FORMULA: pv + ( (Uprediction_2-pv)*(Wprediction_2) + (Uprediction_3-pv)*(Wprediction_3)... )/mp
     _found = False
@@ -33,9 +42,24 @@ def model_per_emotive(ensemble, emotive, potential_normalization_factor):
     return v
 
 def average_emotives(record):
-    '''Averages the emotives in a list (e.g. predictions ensemble or percepts).
+    """
+    Averages the emotives in a list (e.g. predictions ensemble or percepts).
     The emotives in the record are of type: [{'e1': 4, 'e2': 5}, {'e2': 6}, {'e1': 5 'e3': -4}]
-    '''
+
+    Args:
+        record (list): List of emotive dictionaries to average emotives of 
+
+    Returns:
+        dict: Dictionary of Averaged Emotives
+        
+    Example:
+        ..  code-block:: python
+
+            from ia.gaius.prediction_models import average_emotives
+            record = [{'e1': 4, 'e2': 5}, {'e2': 6}, {'e1': 5 'e3': -4}]
+            averages = average_emotives(record=record)
+            
+    """
     new_dict = {}
     for bunch in record:
         for e,v in bunch.items():
@@ -70,7 +94,18 @@ def bucket_predictions(ensemble):
          
     
 def make_modeled_emotives(ensemble):
-    '''The emotives in the ensemble are of type: 'emotives':[{'e1': 4, 'e2': 5}, {'e2': 6}, {'e1': 5 'e3': -4}]'''
+    """
+    The emotives in the ensemble are of type: 'emotives':[{'e1': 4, 'e2': 5}, {'e2': 6}, {'e1': 5 'e3': -4}]
+    First calls :func:`average_emotives` on each prediction in the ensemble, then calls :func:`bucket_predictions` on the ensemble.
+    After bucketing predictions, the function :func:`model_per_emotives` is called for each emotive present in the ensemble.
+    Dict returned contains { emotive: model_per_emotive } for each emotive in the ensemble
+    
+    Args:
+        ensemble (list): Prediction ensemble containing emotives to model
+
+    Returns:
+        dict: Dictionary of modelled emotive values
+    """
     
 
     emotives_set = set()
@@ -90,7 +125,14 @@ def make_modeled_emotives(ensemble):
 
 
 def hive_model_emotives(ensembles):
-    """Average of final node predictions."""
+    """Compute average of emotives in model by calling :func:`average_emotives` on `ensembles`
+
+    Args:
+        ensembles (list): Prediction ensemble to compute average emotives of
+
+    Returns:
+        _type_: _description_
+    """
     return average_emotives(ensembles)
 
 def prediction_ensemble_model_classification(ensemble):
@@ -107,7 +149,14 @@ def prediction_ensemble_model_classification(ensemble):
         return None
 
 def hive_model_classification(ensembles):
-    """Every node gets a vote."""
+    """Compute the "hive predicted model classification" based on the ensembles provided from each node
+
+    Args:
+        ensembles (dict): should be dictionary of { node_name: prediction_ensemble }
+
+    Returns:
+        str: hive predicted classification
+    """
     if ensembles:
         # This just takes the first "most common", even if there are multiple that have the same frequency.
         boosted_classifications = [prediction_ensemble_model_classification(c) for c in ensembles.values()]
